import type { AnyTxtNode, TxtParentNode, TxtStrNode, TxtTextNode } from "@textlint/ast-node-types";
import { SourceCode } from "./parser/SourceCode.js";
import { AbstractParser } from "./parser/AbstractParser.js";
import { SeparatorParserOptions } from "./parser/SeparatorParser.js";
export declare const SentenceSplitterSyntax: {
    readonly WhiteSpace: "WhiteSpace";
    readonly Punctuation: "Punctuation";
    readonly Sentence: "Sentence";
    readonly Str: "Str";
};
export type TxtSentenceNode = Omit<TxtParentNode, "type"> & {
    readonly type: "Sentence";
};
export type TxtWhiteSpaceNode = Omit<TxtTextNode, "type"> & {
    readonly type: "WhiteSpace";
};
export type TxtPunctuationNode = Omit<TxtTextNode, "type"> & {
    readonly type: "Punctuation";
};
export type SentenceSplitterTxtNode = TxtSentenceNode | TxtWhiteSpaceNode | TxtPunctuationNode | TxtStrNode | AnyTxtNode;
export type SentenceSplitterTxtNodeType = (typeof SentenceSplitterSyntax)[keyof typeof SentenceSplitterSyntax];
export declare class SplitParser {
    private nodeList;
    private results;
    source: SourceCode;
    constructor(text: string | TxtParentNode);
    get current(): TxtSentenceNode | undefined;
    pushNodeToCurrent(node: SentenceSplitterTxtNode): void;
    open(parentNode: TxtSentenceNode): void;
    isOpened(): boolean;
    nextLine(parser: AbstractParser): {
        line: number;
        column: number;
        offset: number;
    };
    nextSpace(parser: AbstractParser): void;
    nextValue(parser: AbstractParser): void;
    close(parser: AbstractParser): void;
    toList(): SentenceSplitterTxtNode[];
}
export interface splitOptions {
    /**
     * Separator options
     */
    SeparatorParser?: SeparatorParserOptions;
}
/**
 * split `text` into Sentence nodes
 */
export declare function split(text: string, options?: splitOptions): SentenceSplitterTxtNode[];
/**
 * Convert Paragraph Node to Paragraph node that convert children to Sentence node
 * This Node is based on TxtAST.
 * See https://github.com/textlint/textlint/blob/master/docs/txtnode.md
 */
export declare function splitAST(paragraphNode: TxtParentNode, options?: splitOptions): SentenceSplitterTxtNode;
//# sourceMappingURL=sentence-splitter.d.ts.map